@@ -13,7 +13,8 @@ import pickle
 parser = ConfigParser()
 cwd = os.path.dirname(os.path.abspath(__file__))
 
-config_file = os.path.join(cwd, r'configuration.ini')
+config_file = r'./configuration.ini'
+
 parser.read(config_file)
 
 class Sorn(object):
